# Table of Contents

- [synchronizing-projects-between-sap-cloud-alm-and-sap-leanix](<./synchronizing-projects-between-sap-cloud-alm-and-sap-leanix.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Synchronizing Projects Between SAP Cloud ALM and SAP LeanIX](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX.md>)
  - [Introduction](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX/Introduction.md>)
  - [Synchronizing a Project to an Existing Fact Sheet](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX/Synchronizing-a-Project-to-an-Existing-Fact-Sheet.md>)
  - [Importing a Project as a New Fact Sheet](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX/Importing-a-Project-as-a-New-Fact-Sheet.md>)
  - [Importing More Projects](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX/Importing-More-Projects.md>)
  - [Exporting an Initiative to SAP Cloud ALM](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX/Exporting-an-Initiative-to-SAP-Cloud-ALM.md>)
  - [Running Manual Synchronization](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX/Running-Manual-Synchronization.md>)
  - [Delinking a Fact Sheet to Stop Synchronization](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX/Delinking-a-Fact-Sheet-to-Stop-Synchronization.md>)
  - [Navigating Between SAP LeanIX and SAP Cloud ALM](<./Synchronizing-Projects-Between-SAP-Cloud-ALM-and-SAP-LeanIX/Navigating-Between-SAP-LeanIX-and-SAP-Cloud-ALM.md>)
